from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_PIC32 = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'PIC32MK1024GPD100-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MK1024GPD100-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_12x12mm_P0.4mm'], 'footprint':'Package_QFP:TQFP-100_12x12mm_P0.4mm', 'keywords':'32-bit MIPS MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC32MK_GP_MC_Familly_Datasheet_60001402G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MK1024GPD100-xPT\n\n32-bit MIPS MCU Microcontroller', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RG6/VBUSON2',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='RA10/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='RG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RA12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGD3/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGC3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGC1/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGD1/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RF9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RF10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA7/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RG11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RB14/VBUSON1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RE12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RE13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RE14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RE15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RA8/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VBUS1',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='VUSB3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VBUS2',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='D2-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='D2+',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='RC12/OSCI/CLKI',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RC15/OSCO/CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='PGD2/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PGC2/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RC10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='RC13/SOSCI',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='SOSCO/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='TMS/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='TRCLK/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='TRD3/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14/TRD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='RB13',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MM0064GPL028x-ML', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MM0064GPL028x-ML'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm'], 'footprint':'Package_DFN_QFN:QFN-28-1EP_6x6mm_P0.65mm_EP4.25x4.25mm', 'keywords':'FLASH-Based 32-Bit CMOS Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC32MM0064GPL036-Family-Data-Sheet-DS60001324C.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MM0064GPL028x-ML\n\nFLASH-Based 32-Bit CMOS Microcontroller', 'pins':[
            Pin(num='1',name='RBO',func=pin_types.BIDIR),
            Pin(num='10',name='VDD',func=pin_types.PWRIN),
            Pin(num='11',name='RB5',func=pin_types.BIDIR),
            Pin(num='12',name='RB6',func=pin_types.BIDIR),
            Pin(num='13',name='RB7',func=pin_types.BIDIR),
            Pin(num='14',name='RB8',func=pin_types.BIDIR),
            Pin(num='15',name='RB9',func=pin_types.BIDIR),
            Pin(num='16',name='RC9',func=pin_types.BIDIR),
            Pin(num='17',name='VCAP',func=pin_types.PWROUT),
            Pin(num='18',name='RB10',func=pin_types.BIDIR),
            Pin(num='19',name='RB11',func=pin_types.BIDIR),
            Pin(num='2',name='RB1',func=pin_types.BIDIR),
            Pin(num='20',name='RB12',func=pin_types.BIDIR),
            Pin(num='21',name='RB13',func=pin_types.BIDIR),
            Pin(num='22',name='RB14',func=pin_types.BIDIR),
            Pin(num='23',name='RB15',func=pin_types.BIDIR),
            Pin(num='24',name='AVSS',func=pin_types.PWRIN),
            Pin(num='25',name='AVDD',func=pin_types.PWRIN),
            Pin(num='26',name='~{MCLR}',func=pin_types.INPUT),
            Pin(num='27',name='RA0',func=pin_types.BIDIR),
            Pin(num='28',name='RA1',func=pin_types.BIDIR),
            Pin(num='29',name='EP',func=pin_types.PASSIVE),
            Pin(num='3',name='RB2',func=pin_types.BIDIR),
            Pin(num='4',name='RB3',func=pin_types.BIDIR),
            Pin(num='5',name='VSS',func=pin_types.PWRIN),
            Pin(num='6',name='RA2',func=pin_types.BIDIR),
            Pin(num='7',name='RA3',func=pin_types.BIDIR),
            Pin(num='8',name='RB4',func=pin_types.BIDIR),
            Pin(num='9',name='RA4',func=pin_types.BIDIR)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX110F016D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX110F016D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX110F016D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX210F016D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX210F016D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX210F016D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX575F256H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX575F256H'}), 'ref_prefix':'U', 'fplist':[''], 'footprint':'', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/61156G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX575F256H\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='VUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX795F512L-80x-PF', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX795F512L-80x-PF'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_14x14mm_P0.5mm'], 'footprint':'Package_QFP:TQFP-100_14x14mm_P0.5mm', 'keywords':'32-bit MIPS MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001156J.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX795F512L-80x-PF\n\n32-bit MIPS MCU Microcontroller', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='RA0/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC1/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED1/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC2/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED2/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RA1/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='VUSB3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='RG3/D-',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='RG2/D+',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RA4/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RA5/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='RC12/OSC1/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RC15/OSC2/CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='RC13/SOSCI',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='RC14/SOSCO',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP/VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='RA6/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='RA7/TRD3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14/TRD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX795F512L-80x-PT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX795F512L-80x-PT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_12x12mm_P0.4mm'], 'footprint':'Package_QFP:TQFP-100_12x12mm_P0.4mm', 'keywords':'32-bit MIPS MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001156J.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX795F512L-80x-PT\n\n32-bit MIPS MCU Microcontroller', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='RA0/TMS',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGEC1/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGED1/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGEC2/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGED2/RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RA9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RA1//TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RF2',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RF8',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='VUSB3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='RG3/D-',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='RG2/D+',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='RA2',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RA3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RA4/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RA5/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='RC12/OSC1/CLK',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RC15/OSC2/CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='69',name='RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='RC13/SOSCI',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='RC14/SOSCO',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RC3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VCAP/VDDCORE',func=pin_types.PWROUT,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RC4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='RA6/TRCLK',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='RA7/TRD3',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14/TRD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12/TRD1',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='RE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MK1024GPE100-xPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MK1024GPE100-xPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-100_12x12mm_P0.4mm', 'Package_QFP:TQFP-100_12x12mm_P0.4mm'], 'footprint':'Package_QFP:TQFP-100_12x12mm_P0.4mm', 'keywords':'32-bit MIPS MCU Microcontroller', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/PIC32MK_GP_MC_Familly_Datasheet_60001402G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MK1024GPE100-xPT\n\n32-bit MIPS MCU Microcontroller', 'pins':[
            Pin(num='1',name='RG15',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RG6/VBUSON2',func=pin_types.BIDIR,unit=1),
            Pin(num='100',name='RA10/TDO',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='14',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='RG10',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RE8',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='RE9',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='RA12',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='RA11',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RA0',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RA1',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PGD3/RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PGC3/RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PGC1/RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PGD1/RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RF9',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RF10',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RA7/TCK',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='31',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='RC0',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RC1',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='RC2',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='RC11',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='37',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='38',name='RG11',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='RF13',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RB14/VBUSON1',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RF12',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='RE12',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='RE13',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RE14',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RE15',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='46',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='47',name='RD14',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RD15',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RA8/TDI',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RA4',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='VBUS1',func=pin_types.INPUT,unit=1),
            Pin(num='55',name='VUSB3V3',func=pin_types.PWRIN,unit=1),
            Pin(num='56',name='D1-',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='D1+',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='VBUS2',func=pin_types.INPUT,unit=1),
            Pin(num='59',name='D2-',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='D2+',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='63',name='RC12/OSCI/CLKI',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RC15/OSCO/CLKO',func=pin_types.BIDIR,unit=1),
            Pin(num='65',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='66',name='RA14',func=pin_types.BIDIR,unit=1),
            Pin(num='67',name='RA15',func=pin_types.BIDIR,unit=1),
            Pin(num='68',name='VBAT',func=pin_types.PWRIN,unit=1),
            Pin(num='69',name='PGD2/RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='70',name='PGC2/RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='71',name='RC10',func=pin_types.BIDIR,unit=1),
            Pin(num='72',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='73',name='RC13/SOSCI',func=pin_types.BIDIR,unit=1),
            Pin(num='74',name='SOSCO/RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='75',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='76',name='TMS/RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='77',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='78',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='79',name='RD12',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='80',name='RD13',func=pin_types.BIDIR,unit=1),
            Pin(num='81',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='82',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='83',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='84',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='85',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='86',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='87',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='88',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='89',name='RG1',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='90',name='RG0',func=pin_types.BIDIR,unit=1),
            Pin(num='91',name='TRCLK/RF6',func=pin_types.BIDIR,unit=1),
            Pin(num='92',name='TRD3/RF7',func=pin_types.BIDIR,unit=1),
            Pin(num='93',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='94',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='95',name='RG14/TRD2',func=pin_types.BIDIR,unit=1),
            Pin(num='96',name='RG12',func=pin_types.BIDIR,unit=1),
            Pin(num='97',name='RG13/TRD0',func=pin_types.BIDIR,unit=1),
            Pin(num='98',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='99',name='RB13',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX120F032D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX120F032D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX120F032D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX130F064D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX130F064D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX130F064D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX150F128D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX150F128D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX150F128D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX170F256D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX170F256D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX170F256D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='RB6',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX220F032D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX220F032D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX220F032D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX230F064D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX230F064D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX230F064D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX250F128D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX250F128D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX250F128D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX270F256D-IPT', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX270F256D-IPT'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'Package_QFP:TQFP-44_10x10mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-44_10x10mm_P0.8mm', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/60001168F.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX270F256D-IPT\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VUSB3V3',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RA10',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RA7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='17',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='19',name='RA0',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='RC6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='RA1',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='RB0',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='RB1',func=pin_types.INPUT,unit=1),
            Pin(num='23',name='RB2',func=pin_types.INPUT,unit=1),
            Pin(num='24',name='RB3',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='RC0',func=pin_types.INPUT,unit=1),
            Pin(num='26',name='RC1',func=pin_types.INPUT,unit=1),
            Pin(num='27',name='RC2',func=pin_types.INPUT,unit=1),
            Pin(num='28',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='RC7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RA2',func=pin_types.INPUT,unit=1),
            Pin(num='31',name='RA3',func=pin_types.INPUT,unit=1),
            Pin(num='32',name='RA8',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='RB4',func=pin_types.INPUT,unit=1),
            Pin(num='34',name='RA4',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='RA9',func=pin_types.INPUT,unit=1),
            Pin(num='36',name='RC3',func=pin_types.INPUT,unit=1),
            Pin(num='37',name='RC4',func=pin_types.INPUT,unit=1),
            Pin(num='38',name='RC5',func=pin_types.INPUT,unit=1),
            Pin(num='39',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='RC8',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='41',name='RB5',func=pin_types.INPUT,unit=1),
            Pin(num='42',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='43',name='RB7',func=pin_types.INPUT,unit=1),
            Pin(num='44',name='RB8',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='RC9',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='VCAP',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='RB11',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PIC32MX575F512H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PIC32MX575F512H'}), 'ref_prefix':'U', 'fplist':['', ''], 'footprint':'', 'keywords':'Microchip PIC32 Microcontroller MIPS', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/61156G.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_PIC32.kicad_sym\nPIC32MX575F512H\n\nMicrochip PIC32 Microcontroller MIPS', 'pins':[
            Pin(num='1',name='RE5',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='RB5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='RB4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='RB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='RB2',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='RB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='RB0',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='RB6',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='RB7',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='RE6',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='RB8',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='RB9',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='RB10',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='RB11',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='26',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='27',name='RB12',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='RB13',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='RB14',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='RE7',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='RB15',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='RF4',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='RF5',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='RF3',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='35',name='VUSB',func=pin_types.PWRIN,unit=1),
            Pin(num='36',name='RG3',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='RG2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='39',name='RC12',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='RG6',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='RC15',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='VSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='42',name='RD8',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='RD9',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='RD10',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='RD11',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='RD0',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='RC13',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='RC14',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='RD1',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='RG7',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='RD2',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='RD3',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='RD4',func=pin_types.BIDIR,unit=1),
            Pin(num='53',name='RD5',func=pin_types.BIDIR,unit=1),
            Pin(num='54',name='RD6',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='RD7',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='VCAP',func=pin_types.PWROUT,unit=1),
            Pin(num='57',name='VDD',func=pin_types.PASSIVE,unit=1),
            Pin(num='58',name='RF0',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='RF1',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='RG8',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='RE0',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='RE1',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='RE2',func=pin_types.BIDIR,unit=1),
            Pin(num='63',name='RE3',func=pin_types.BIDIR,unit=1),
            Pin(num='64',name='RE4',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='~{MCLR}',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='RG9',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])